@@ -342,29 +342,6 @@ sony_collection_sorting_rules = []
 # a book' are added when copying books to another library
 add_new_book_tags_when_importing_books = False
 
-#: Set custom metadata fields that the Content server will or will not display.
-# Controls what fields are displayed when clicking the "Search" button in the
-# browser to search your calibre library.
-# content_server_will_display is a list of custom fields to be displayed.
-# content_server_wont_display is a list of custom fields not to be displayed.
-# wont_display has priority over will_display.
-# The special value '*' means all custom fields. The value [] means no entries.
-# Defaults:
-#    content_server_will_display = ['*']
-#    content_server_wont_display = []
-#
-# Examples:
-#
-# To display only the custom fields #mytags and #genre:
-#   content_server_will_display = ['#mytags', '#genre']
-#   content_server_wont_display = []
-#
-# To display all fields except #mycomments:
-#   content_server_will_display = ['*']
-#   content_server_wont_display['#mycomments']
-content_server_will_display = ['*']
-content_server_wont_display = []
-
 #: Set the maximum number of sort 'levels'
 # Set the maximum number of sort 'levels' that calibre will use to resort the
 # library after certain operations such as searches or device insertion. Each
